==> qtjambi-qt3drender-5.15.9-sources.jar: io/qt/qt3d/render/QMaterial.java <==
package io.qt.qt3d.render;


/**
 * <p>Provides an abstract class that should be the base of all material component classes in a scene</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qmaterial.html">Qt3DRender::QMaterial</a></p>
 */
public class QMaterial extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QMaterial.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qmaterial.html#effect-prop">Qt3DRender::QMaterial::effectChanged(Qt3DRender::QEffect*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="effect")
    public final Signal1<io.qt.qt3d.render.QEffect> effectChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QMaterial(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QMaterial() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QMaterial(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QMaterial instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qmaterial.html#addParameter">Qt3DRender::QMaterial::addParameter(Qt3DRender::QParameter*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addParameter(io.qt.qt3d.render.QParameter parameter){
        addParameter_native_Qt3DRender_QParameter_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parameter));
    }
    
    @io.qt.QtUninvokable
    private native void addParameter_native_Qt3DRender_QParameter_ptr(long __this__nativeId, long parameter);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qmaterial.html#effect-prop">Qt3DRender::QMaterial::effect()const</a></p>
     */
    @io.qt.QtPropertyReader(name="effect")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QEffect effect(){
        return effect_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QEffect effect_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qmaterial.html#parameters">Qt3DRender::QMaterial::parameters()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.render.QParameter> parameters(){
        return parameters_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.render.QParameter> parameters_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qmaterial.html#removeParameter">Qt3DRender::QMaterial::removeParameter(Qt3DRender::QParameter*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeParameter(io.qt.qt3d.render.QParameter parameter){
        removeParameter_native_Qt3DRender_QParameter_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parameter));
    }
    
    @io.qt.QtUninvokable
    private native void removeParameter_native_Qt3DRender_QParameter_ptr(long __this__nativeId, long parameter);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qmaterial.html#effect-prop">Qt3DRender::QMaterial::setEffect(Qt3DRender::QEffect*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="effect")
    public final void setEffect(io.qt.qt3d.render.QEffect effect){
        setEffect_native_Qt3DRender_QEffect_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(effect));
    }
    
    private native void setEffect_native_Qt3DRender_QEffect_ptr(long __this__nativeId, long effect);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QMaterial(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QMaterial(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QMaterial instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-5.15.13-sources.jar: io/qt/qt3d/render/QMaterial.java <==
package io.qt.qt3d.render;


/**
 * <p>Provides an abstract class that should be the base of all material component classes in a scene</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qmaterial.html">Qt3DRender::QMaterial</a></p>
 */
public class QMaterial extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QMaterial.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qmaterial.html#effect-prop">Qt3DRender::QMaterial::effectChanged(Qt3DRender::QEffect*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="effect")
    public final Signal1<io.qt.qt3d.render.QEffect> effectChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QMaterial(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QMaterial() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QMaterial(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QMaterial instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qmaterial.html#addParameter">Qt3DRender::QMaterial::addParameter(Qt3DRender::QParameter*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addParameter(io.qt.qt3d.render.QParameter parameter){
        addParameter_native_Qt3DRender_QParameter_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parameter));
    }
    
    @io.qt.QtUninvokable
    private native void addParameter_native_Qt3DRender_QParameter_ptr(long __this__nativeId, long parameter);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qmaterial.html#effect-prop">Qt3DRender::QMaterial::effect()const</a></p>
     */
    @io.qt.QtPropertyReader(name="effect")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QEffect effect(){
        return effect_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QEffect effect_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qmaterial.html#parameters">Qt3DRender::QMaterial::parameters()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.render.QParameter> parameters(){
        return parameters_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.render.QParameter> parameters_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qmaterial.html#removeParameter">Qt3DRender::QMaterial::removeParameter(Qt3DRender::QParameter*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeParameter(io.qt.qt3d.render.QParameter parameter){
        removeParameter_native_Qt3DRender_QParameter_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parameter));
    }
    
    @io.qt.QtUninvokable
    private native void removeParameter_native_Qt3DRender_QParameter_ptr(long __this__nativeId, long parameter);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qmaterial.html#effect-prop">Qt3DRender::QMaterial::setEffect(Qt3DRender::QEffect*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="effect")
    public final void setEffect(io.qt.qt3d.render.QEffect effect){
        setEffect_native_Qt3DRender_QEffect_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(effect));
    }
    
    private native void setEffect_native_Qt3DRender_QEffect_ptr(long __this__nativeId, long effect);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QMaterial(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QMaterial(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QMaterial instance, QDeclarativeConstructor constructor);
    
}
